@@ -187,18 +187,16 @@ int
 main (int argc, char **argv)
 {
 	CORBA_Environment ev;
-	CORBA_ORB orb;
 	CORBA_exception_init (&ev);
+	GnomeProgram *program;
 
 	/* Encorage -lefence to play ball */
 	{ char *tmp = malloc (4); if (tmp) free (tmp); }
 
-	gnome_program_init ("test-sensitivity", VERSION,
+	program = gnome_program_init ("test-sensitivity", VERSION,
 			    LIBBONOBOUI_MODULE,
 			    argc, argv, NULL);
 
-	orb = bonobo_orb ();
-
 	/*
 	 * We can't make any CORBA calls unless we're in the main
 	 * loop.  So we delay creating the container here.
@@ -207,5 +205,7 @@ main (int argc, char **argv)
 
 	bonobo_main ();
 
+	g_object_unref (program);
+
 	return bonobo_ui_debug_shutdown ();
 }
